rio-joydivision
===============

.. figure:: https://cloud.githubusercontent.com/assets/5084513/10010135/4cb38740-609b-11e5-92e4-348852a7d361.png
   :alt: image

   image

Streams out moody post-punk geojson w/ y-offsets derived from raster
data

::

    Usage: rio joydivision [OPTIONS] INPUTFILE

      LOVE

          WILL

              TEAR

                  US

                      APART

    Options:
      -r, --row-interval INTEGER  Row interval to sample on [default = 1]
      -c, --col-interval INTEGER  Column interval to sample on [default = 1]
      -f, --scaling-factor FLOAT  Value to scale y-offset by [default = 1.0]
      -n, --nodata-set TEXT       Value to set nodata to [default = None]
      --version                   Show the version and exit.
      --help                      Show this message and exit.
